@@ -1,4 +1,4 @@
-# $Id: mvt.R 187 2008-07-02 12:02:34Z thothorn $ 
+# $Id: mvt.R 188 2008-07-08 07:33:41Z thothorn $ 
 
 checkmvArgs <- function(lower, upper, mean, corr, sigma) 
 {
@@ -220,7 +220,7 @@ dmvt <- function(x, delta, sigma, df = 1, log = TRUE)
     if (NCOL(x) != NCOL(sigma)) {
         stop("x and sigma have non-conforming size")
     }
-    if (!isSymmetric(sigma)) {
+    if (!isSymmetric(sigma, tol = sqrt(.Machine$double.eps))) {
         stop("sigma must be a symmetric matrix")
     }
     if (length(delta) != NROW(sigma)) {
